// Copyright 2015 Matthew Holt and The Caddy Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//go:build gofuzz

package caddy

func FuzzReplacer(data []byte) (score int) {
	NewReplacer().ReplaceAll(string(data), "")
	NewReplacer().ReplaceAll(NewReplacer().ReplaceAll(string(data), ""), "")
	NewReplacer().ReplaceAll(NewReplacer().ReplaceAll(string(data), ""), NewReplacer().ReplaceAll(string(data), ""))
	NewReplacer().ReplaceAll(string(data[:len(data)/2]), string(data[len(data)/2:]))
	return 0
}
